@@ -40,6 +40,7 @@ export class RobotModel {
   node: Konva.Image | Konva.Path;
   points: any = [];
   traceColor: string = 'red';
+  speed: number = 1;
 
   world: WorldModel;
 
@@ -58,6 +59,7 @@ export class RobotModel {
     this.image = image;
     this.world = world;
     this.canvas = this.world.ui.layers.main;
+    this.speed = 1;
   }
 
   cr2xy(x: number, y: number) {
@@ -97,6 +99,10 @@ export class RobotModel {
     this.add_point(this.x, this.y);
   }
 
+  set_speed(speed: number) {
+    this.speed = speed;
+  }
+
   clear_trace() {
     this.points = [];
     this.world.ui.layers.line.destroyChildren();
@@ -110,7 +116,7 @@ export class RobotModel {
         node: this.node,
         x: cx,
         y: cy,
-        duration: 2,
+        duration: this.speed,
         onFinish: () => {
           this.x = x;
           this.y = y;
@@ -131,7 +137,7 @@ export class RobotModel {
       let tween = new Konva.Tween({
         node: this.node,
         rotation: mod(-90 * this.orientation, 360),
-        duration: 2,
+        duration: this.speed,
         x: cx,
         y: cy,
         onFinish: () => {
