@@ -111,6 +111,10 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.robots[index]?.set_trace(color);
   };
 
+  set_speed = (index: number, speed: number) => {
+    return this.world_model.robots[index]?.set_speed(speed);
+  };
+
   add_wall = (x: number, y: number, dir: string) => {
     return this.world_model.draw_wall(x, y, dir);
   };
