@@ -3,6 +3,7 @@ _directions = [(1,0), (0,1), (-1,0), (0,-1)]
 dir_names = ["east", "north","west", "south"]
 
 from .models.world_model import print_success, print_error
+import time as _time
 
 class Robot():
     def __init__(self, index, robot_model, world):
@@ -11,6 +12,7 @@ class Robot():
         self.world = world
         self.index = index
         self.collections = {}
+        self.speed  = 0.5
  
     @property
     def x(self):
@@ -40,6 +42,7 @@ class Robot():
         for x in range(step):
             self._move()
         self.world.js_call('move_to',[self.index, self.x, self.y])
+        _time.sleep(self.speed)
     
     def _move(self):
         if self.front_is_clear():
@@ -60,7 +63,13 @@ class Robot():
     def is_front_clear(self):
         return self.world_model.is_clear(self.x, self.y, self.dir)
     
-    def wall_in_front(self):
+    def right_is_clear(self):
+        return self.world.model.is_clear(self.x, self.y, (self.dir + 3) % 4)
+    
+    def wall_on_right(self):
+        return not self.right_is_clear()
+    
+    def wall_on_front(self):
         return not self.is_front_clear()
     
     def cell(self):
@@ -85,13 +94,34 @@ class Robot():
     def set_trace(self, color='red'):
         self.world.js_call('set_trace', [self.index, color])
     
-    def on_object(self):
-        k = "{},{}".format(self.x,self.y)
-        obj  = self.world_model.objects.get(k, None)
-        return  obj is not None and obj != self.collections.get(k, None)
+    def set_speed(self, speed=0.1):
+        self.speed = speed
+        self.world.js_call('set_speed', [self.index, speed])
     
-    def pick(self):
-        if self.on_object():
+    def has_object(self, obj_name = None):
+        objs = self.collections.values()
+        if len(objs) > 0:
+            if obj_name is None:
+                return True
+            else:
+                fobjs = filter(lambda x, y: x == obj_name, objs)
+                return sum(fobjs.values)
+        else: 
+            return False
+
+    
+    def on_object(self, obj_type=None):
+        k = "{},{}".format(self.x,self.y)
+        obj = self.world_model.objects.get(k, None)
+        valid_type = True
+        if obj is not None and obj_type is not None:
+            obj_name = next(iter(obj))
+            valid_type =  obj_name == obj_type
+
+        return  obj is not None and valid_type and obj != self.collections.get(k, None) 
+    
+    def pick(self, obj_type=None):
+        if self.on_object(obj_type):
             ck = "{},{}".format(self.x,self.y)
         
             obj = self.world_model.objects.get(ck, None)
